@@ -1,7 +1,8 @@
 """ Includes custom types used in schemas
 """
 import datetime
-from typing import Tuple, Union
+from enum import Enum
+from typing import Literal, Tuple, Union
 
 from eolearn.core import FeatureType
 
@@ -12,3 +13,11 @@ TimePeriod = Tuple[datetime.date, datetime.date]
 
 Feature = Tuple[FeatureType, str]
 FeatureSpec = Union[Tuple[FeatureType, str], FeatureType]
+
+BoolOrAuto = Union[Literal["auto"], bool]
+
+
+class ProcessingType(Enum):
+    RAY = "ray"
+    SINGLE = "single"
+    MULTI = "multi"
